# Examples

This section provides practical examples to help you get started with MNELAB and understand its capabilities for various EEG/MEG analysis tasks.

- [Compute and visualize ERDS maps](erds_maps.md)
- [Event-Related Potentials (ERPs)](erp.md)

*Browse through the examples to see step-by-step guides on using MNELAB.*
